import os
from unittest import TestCase

from utils_base import Directory


class TestDirectory(TestCase):
    def test_init(self):
        dir_tests = Directory(os.path.join('src', 'utils'))
        self.assertEqual(dir_tests.path, os.path.join('src', 'utils'))
        self.assertEqual(dir_tests.name, 'utils')



import unittest

from utils_base import Log, _log


class TestCase(unittest.TestCase):
    def test_log(self):
        for __log in [_log, Log('custom')]:
            self.assertIsNotNone(__log)
            for func in [
                __log.debug,
                __log.info,
                __log.warning,
                __log.error,
                __log.critical,
            ]:
                print('before')
                func('test')
                print('after')


if __name__ == '__main__':
    unittest.main()



def _clean_(x: str) -> str:
    return x.strip().lower().replace(',', '')


def parse_int(x) -> int:
    try:
        return int(_clean_(x))
    except ValueError:
        return None


def parse_float(x) -> float:
    try:
        return float(_clean_(x))
    except ValueError:
        return None



from utils_base.ds.Dict import Dict
from utils_base.ds.List import List
from utils_base.ds.parses import parse_float, parse_int
from utils_base.ds.String import String
from utils_base.file.CSVFile import CSVFile
from utils_base.file.Directory import Directory
from utils_base.file.File import File
from utils_base.file.FiledVariable import FiledVariable
from utils_base.file.JSONFile import JSONFile
from utils_base.file.PDFFile import PDFFile
from utils_base.file.TSVFile import TSVFile
from utils_base.file.XSVFile import XSVFile
from utils_base.file.Zip import Zip
from utils_base.geo.LatLng import LatLng
from utils_base.geo.LatLngLK import LatLngLK
from utils_base.image.Image import Image
from utils_base.Log import Log, _log
from utils_base.time.Time import Time
from utils_base.time.TimeDelta import TimeDelta
from utils_base.time.TimeFormat import (TIME_FORMAT_DATE, TIME_FORMAT_DATE_ID,
                                        TIME_FORMAT_TIME, TIME_FORMAT_TIME_ID,
                                        TimeFormat)
from utils_base.time.TimeID import get_date_id, get_time_id
from utils_base.time.TimeUnit import DAYS_IN, SECONDS_IN, TimeUnit
from utils_base.time.TIMEZONE_OFFSET import TIMEZONE_OFFSET
from utils_base.xmlx import _

# Deprecated Classes, but deleted from dependencies
Color = None
Table, TableRow = None, None



"""Utils."""

import logging


class COLOR_FORMAT:
    RESET = '\033[0m'  # noqa
    BOLD = '\033[01m'  # noqa
    FAINT = '\033[02m'  # noqa
    ITALIC = '\033[03m'  # noqa
    UNDERLINE = '\033[04m'  # noqa

    REVERSE = '\033[07m'  # noqa
    INVISIBLE = '\033[08m'  # noqa
    STRIKETHROUGH = '\033[09m'  # noqa


class COLOR_FOREGROUND:
    BLACK = '\033[30m'  # noqa
    RED = '\033[31m'  # noqa
    GREEN = '\033[32m'  # noqa
    YELLOW = '\033[33m'  # noqa
    BLUE = '\033[34m'  # noqa
    MAGENTA = '\033[35m'  # noqa
    CYAN = '\033[36m'  # noqa
    LIGHT_GRAY = '\033[37m'  # noqa
    GRAY = '\033[90m'  # noqa
    LIGHT_RED = '\033[91m'  # noqa
    LIGHT_GREEN = '\033[92m'  # noqa
    LIGHT_YELLOW = '\033[93m'  # noqa
    LIGHT_BLUE = '\033[94m'  # noqa
    LIGHT_MAGENTA = '\033[95m'  # noqa
    LIGHT_CYAN = '\033[96m'  # noqa
    WHITE = '\033[97m'  # noqa


class COLOR_BACKGROUND:  # noqa
    BLACK = '\033[40m'  # noqa
    RED = '\033[41m'  # noqa
    GREEN = '\033[42m'  # noqa
    YELLOW = '\033[43m'  # noqa
    BLUE = '\033[44m'  # noqa
    MAGENTA = '\033[45m'  # noqa
    CYAN = '\033[46m'  # noqa
    LIGHT_GRAY = '\033[47m'  # noqa
    GRAY = '\033[100m'  # noqa
    LIGHT_RED = '\033[101m'  # noqa
    LIGHT_GREEN = '\033[102m'  # noqa
    LIGHT_YELLOW = '\033[103m'  # noqa
    LIGHT_BLUE = '\033[104m'  # noqa
    LIGHT_MAGENTA = '\033[105m'  # noqa
    LIGHT_CYAN = '\033[106m'  # noqa
    WHITE = '\033[107m'  # noqa


LEVEL_TO_FORMAT_CMDS = {
    logging.CRITICAL: [COLOR_FOREGROUND.MAGENTA, COLOR_FORMAT.BOLD],
    logging.ERROR: [COLOR_FOREGROUND.RED],
    logging.WARNING: [COLOR_FOREGROUND.YELLOW],
    logging.INFO: [COLOR_FOREGROUND.GREEN],
    logging.DEBUG: [COLOR_FOREGROUND.GRAY, COLOR_FORMAT.FAINT],
    logging.NOTSET: [COLOR_FOREGROUND.GRAY],
}


class CustomLoggingFormatter(logging.Formatter):
    def format(self, record):
        format_cmds = LEVEL_TO_FORMAT_CMDS[record.levelno]
        return (
            ''.join(format_cmds)
            + (f'[{record.name}] ' if record.name else '')
            + record.msg
            + COLOR_FORMAT.RESET
        )


class Log(logging.Logger):
    def __init__(self, name: str, level: int = logging.DEBUG):
        super(Log, self).__init__(name, level)
        self.propagate = False

        formatter = CustomLoggingFormatter()
        sh = logging.StreamHandler()
        sh.setLevel(logging.DEBUG)
        sh.setFormatter(formatter)
        self.handlers = [sh]  # noqa


_log = Log('')
